require 'omniauth-oauth2'

module OmniAuth
  module Strategies
    class Voupe < OmniAuth::Strategies::OAuth2

      # Set the site
      option :client_options, { site: "https://portal.voupe.com" }

      # Always request the 'email' when authenticating using Omniauth.
      option :authorize_params, { scope: "email" }
      # option :authorize_options, [:prompt]

      # Set the UID
      uid { raw_info['uuid'] }

      # Set the all the default info properties as best we can
      info do
        {
          'email' => raw_info['email'],
          'name' => raw_info['name'],
          'first_name' => raw_info['first_name'],
          'last_name' => raw_info['last_name'],
          'admin' => raw_info['admin']
        }
      end

      # Provide access to the user's raw info
      extra do
        {'raw_info' => raw_info}
      end

      # Set the callback URL
      def callback_url
        full_host + script_name + callback_path
      end

      # Return all the raw information for the user
      def raw_info
        @raw_info ||= access_token.get('/oauth/api/profile.json').parsed
      end

    end
  end
end
